@@ -8,6 +8,7 @@ use namespace::autoclean;
 
 with 'PDK::Device::Base';
 
+
 has prompt => (is => 'ro', required => 1, default => '^\s*\S+[#>]\s*$',);
 
 has enPrompt => (is => 'ro', required => 0, default => '^\s*\S+[>]\s*$',);
@@ -25,14 +26,39 @@ sub errCodes {
 }
 
 sub waitfor {
-  my ($self, $prompt) = @_;
+  my ($self, $prompt, $params) = @_;
+
+  croak "当同时定义 prompt 和 params 时，'params' 必须是一个哈希引用" if $prompt && $params && ref($params) ne 'HASH';
 
   my $buff = "";
+
   $prompt //= $self->{prompt};
 
   my $exp = $self->{exp};
-  my @ret = $exp->expect(
-    45,
+
+  my $exp_rule;
+  if ($prompt && not defined $params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        $buff .= $exp->before() . $exp->match();
+      }
+    ];
+  }
+  elsif ($prompt && $params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        my $send     = $params->{send}     // '';
+        my $continue = $params->{continue} // 0;
+        my $cache    = $params->{cache}    // 1;
+
+        $self->send($send)                      if !!$send;
+        $buff .= $exp->before() . $exp->match() if !!$cache;
+        exp_continue                            if !!$continue;
+      }
+    ];
+  }
+
+  my $handles = [
     [
       qr/^.+more\s*.+$/mi => sub {
         $self->send(" ");
@@ -61,28 +87,26 @@ sub waitfor {
         exp_continue;
       }
     ],
-    [
-      qr/$prompt/mi => sub {
-        $buff .= $exp->before() . $exp->match();
-      }
-    ],
     [
       eof => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
-  );
+  ];
+
+  splice(@{$handles}, -2, 0, $exp_rule);
+
+  my @ret = $exp->expect($self->{timeout}, @{$handles});
 
   croak($ret[3]) if defined $ret[1];
 
   $buff =~ s/\r\n|\n+\n/\n/g;
   $buff =~ s/\x{08}+\s+\x{08}+//g;
-
   $buff =~ s/\x0D\[\s*#+\s*\]?\s*\d{1,2}%//g;
   $buff =~ s/\x1B\[K//g;
   $buff =~ s/\x0D//g;
@@ -97,13 +121,9 @@ sub runCommands {
 
   $self->{mode} = 'deployCommands';
 
-  if ($commands->[0] !~ /conf/i) {
-    unshift @$commands, 'configure terminal';
-  }
+  unshift @$commands, 'configure terminal' if $commands->[0] !~ /conf/i;
 
-  unless ($commands->[-1] =~ /(copy run|write)/i) {
-    push @$commands, 'copy running-config startup-config';
-  }
+  push @$commands, 'copy running-config startup-config' unless $commands->[-1] =~ /(copy run|write)/i;
 
   $self->execCommands($commands);
 }
@@ -121,8 +141,6 @@ sub getConfig {
   else {
     my $lines = $config->{result};
     $lines =~ s/^\s*ntp\s+clock-period\s+\d+\s*$//mi;
-
-
     return {success => 1, config => $lines};
   }
 }
@@ -130,22 +148,19 @@ sub getConfig {
 sub ftpConfig {
   my ($self, $hostname, $server) = @_;
 
+  $server ||= $ENV{PDK_FTP_SERVER};
+
+  croak "请正确提供 FTP 服务器地址!" unless !!$server;
+
   if (!$self->{exp}) {
     my $login = $self->login();
     croak $login->{reason} if $login->{success} == 0;
   }
 
-  $server ||= $ENV{PDK_FTP_SERVER};
-
   my $host    = $self->{host};
   my $command = "copy running-config ftp://$server/$self->{month}/$self->{date}/";
 
-  if (!!$hostname) {
-    $command .= $hostname . '_' . $host . '.cfg';
-  }
-  else {
-    $command .= $host . '.cfg';
-  }
+  $command .= $hostname ? $hostname . '_' . $host . '.txt' : $host . '.txt';
 
   $self->dump("正在执行FTP备份任务");
   my $result = $self->execCommands([$command]);
