@@ -8,7 +8,7 @@ use namespace::autoclean;
 
 with 'PDK::Device::Base';
 
-has prompt => (is => 'ro', required => 1, default => '^\s*[<\[].*?[>\]]\s*$',);
+has prompt => (is => 'ro', required => 1, default => '^\s*(\x00)?[<\[].*?[>\]]\s*$',);
 
 sub errCodes {
   my $self = shift;
@@ -20,15 +20,39 @@ sub errCodes {
 }
 
 sub waitfor {
-  my ($self, $prompt) = @_;
+  my ($self, $prompt, $params) = @_;
+
+  croak "当同时定义 prompt 和 params 时，'params' 必须是一个哈希引用" if $prompt && $prompt && ref($params) ne 'HASH';
 
   my $buff = "";
+
   $prompt //= $self->{prompt};
 
   my $exp = $self->{exp};
 
-  my @ret = $exp->expect(
-    45,
+  my $exp_rule;
+  if ($prompt && !$params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        $buff .= $exp->before() . $exp->match();
+      }
+    ];
+  }
+  elsif ($prompt && $params) {
+    $exp_rule = [
+      qr/$prompt/mi => sub {
+        my $send     = $params->{send}     // '';
+        my $continue = $params->{continue} // 0;
+        my $cache    = $params->{cache}    // 1;
+
+        $self->send($send)                      if !!$send;
+        $buff .= $exp->before() . $exp->match() if !!$cache;
+        exp_continue                            if !!$continue;
+      }
+    ];
+  }
+
+  my $handles = [
     [
       qr/---- More ----.*$/mi => sub {
         $self->send(" ");
@@ -57,22 +81,21 @@ sub waitfor {
         exp_continue;
       }
     ],
-    [
-      qr/$prompt/mi => sub {
-        $buff .= $exp->before() . $exp->match();
-      }
-    ],
     [
       eof => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[waitfor/自动交互执行回显]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
-  );
+  ];
+
+  splice(@{$handles}, -2, 0, $exp_rule);
+
+  my @ret = $exp->expect($self->{timeout}, @{$handles});
 
   croak($ret[3]) if defined $ret[1];
 
@@ -90,13 +113,9 @@ sub runCommands {
 
   $self->{mode} = 'deployCommands';
 
-  if ($commands->[0] !~ /^sy/i) {
-    unshift @$commands, 'system-view';
-  }
+  unshift @$commands, 'system-view' if $commands->[0] !~ /^sy/i;
 
-  unless ($commands->[-1] =~ /^(sa|write)/i) {
-    push @$commands, 'save force';
-  }
+  push @$commands, 'save force' unless $commands->[-1] =~ /^(sa|write)/i;
 
   $self->execCommands($commands);
 }
@@ -122,26 +141,21 @@ sub getConfig {
 sub ftpConfig {
   my ($self, $hostname, $server, $username, $password) = @_;
 
-  if (!$self->{exp}) {
-    my $login = $self->login();
-    croak $login->{reason} if $login->{success} == 0;
-  }
-
   $server   //= $ENV{PDK_FTP_SERVER};
   $username //= $ENV{PDK_FTP_USERNAME};
   $password //= $ENV{PDK_FTP_PASSWORD};
 
   croak "请正确提供 FTP 服务器地址、账户和密码!" unless $username and $password and $server;
 
+  if (!$self->{exp}) {
+    my $login = $self->login();
+    croak $login->{reason} if $login->{success} == 0;
+  }
+
   my $host    = $self->{host};
   my $command = "put startup.cfg $self->{month}/$self->{date}/";
 
-  if (!!$hostname) {
-    $command .= $hostname . '_' . $host . '.cfg';
-  }
-  else {
-    $command .= $host . '.cfg';
-  }
+  $command .= $hostname ? $hostname . '_' . $host . '.txt' : $host . '.txt';
 
   my $exp    = $self->{exp};
   my $result = $exp ? ($exp->match() || '') : '';
@@ -165,12 +179,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/登录FTP服务器]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
@@ -192,12 +206,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查是否成功登录FTP]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
@@ -221,12 +235,12 @@ sub ftpConfig {
     ],
     [
       eof => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话丢失，连接被意外关闭！具体原因" . $exp->before());
       }
     ],
     [
       timeout => sub {
-        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！具体原因：\n" . $exp->before());
+        croak("执行[ftpConfig/检查备份任务是否成功]，与设备 $self->{host} 会话超时，请检查网络连接或服务器状态！");
       }
     ],
   );
